| Title: | Power analysis for CyTOF experiments |
|---|---|
| Description: | This package is a tool to predict the power of CyTOF experiments in the context of differential state analyses. The package provides a shiny app with two options to predict the power of an experiment: i. generation of in-sicilico CyTOF data, using users input ii. browsing in a grid of parameters for which the power was already precomputed. |
| Authors: | Anne-Maud Ferreira [cre, aut] (ORCID: <https://orcid.org/0000-0002-4749-746X>), Catherine Blish [aut], Susan Holmes [aut] |
| Maintainer: | Anne-Maud Ferreira <[email protected]> |
| License: | LGPL-3 |
| Version: | 1.19.1 |
| Built: | 2026-05-11 22:08:48 UTC |
| Source: | https://github.com/bioc/CyTOFpower |
This package provides functions and a shiny app to predict the power of a CyTOF experiment.
Interactive shiny app to predict the power of a CyTOF experiment.
CyTOFpower()CyTOFpower()
Interactive shiny app.
# Launch the shiny app if (interactive()) { CyTOFpower() }# Launch the shiny app if (interactive()) { CyTOFpower() }